==> h2o-java-rest-bindings-3.8.2.2-sources.jar: water/bindings/pojos/ModelMetricsGLRMV99.java <==
package water.bindings.pojos;

import com.google.gson.Gson;
public class ModelMetricsGLRMV99 extends ModelMetricsBase {
    /** Sum of Squared Error (Numeric Cols) */
    public double numerr;

    /** Misclassification Error (Categorical Cols) */
    public double caterr;

    /** Number of Non-Missing Numeric Values */
    public long numcnt;

    /** Number of Non-Missing Categorical Values */
    public long catcnt;

    /* INHERITED: The model used for this scoring run. 
     * public ModelKeyV3 model;
     */

    /* INHERITED: The checksum for the model used for this scoring run. 
     * public long model_checksum;
     */

    /* INHERITED: The frame used for this scoring run. 
     * public FrameKeyV3 frame;
     */

    /* INHERITED: The checksum for the frame used for this scoring run. 
     * public long frame_checksum;
     */

    /* INHERITED: Optional description for this scoring run (to note out-of-bag, sampled data, etc.) 
     * public String description;
     */

    /* INHERITED: The category (e.g., Clustering) for the model used for this scoring run. 
     * public ModelCategory model_category;
     */

    /* INHERITED: The time in mS since the epoch for the start of this scoring run. 
     * public long scoring_time;
     */

    /* INHERITED: Predictions Frame. 
     * public FrameV3 predictions;
     */

    /* INHERITED: The Mean Squared Error of the prediction for this scoring run. 
     * public double MSE;
     */

    /** Return the contents of this object as a JSON String. */
    @Override
    public String toString() {
        return new Gson().toJson(this);
    }
}

==> h2o-java-rest-bindings-3.8.2.4-sources.jar: water/bindings/pojos/ModelMetricsGLRMV99.java <==
package water.bindings.pojos;

import com.google.gson.Gson;

public class ModelMetricsGLRMV99 extends ModelMetricsBase {
    /** Sum of Squared Error (Numeric Cols) */
    public double numerr;

    /** Misclassification Error (Categorical Cols) */
    public double caterr;

    /** Number of Non-Missing Numeric Values */
    public long numcnt;

    /** Number of Non-Missing Categorical Values */
    public long catcnt;

    /* INHERITED: The model used for this scoring run. 
    public ModelKeyV3 model = null;
     */

    /* INHERITED: The checksum for the model used for this scoring run. 
    public long model_checksum = 0L;
     */

    /* INHERITED: The frame used for this scoring run. 
    public FrameKeyV3 frame = null;
     */

    /* INHERITED: The checksum for the frame used for this scoring run. 
    public long frame_checksum = 0L;
     */

    /* INHERITED: Optional description for this scoring run (to note out-of-bag, sampled data, etc.) 
    public String description = "";
     */

    /* INHERITED: The category (e.g., Clustering) for the model used for this scoring run. 
    public ModelCategory model_category = null;
     */

    /* INHERITED: The time in mS since the epoch for the start of this scoring run. 
    public long scoring_time = 0L;
     */

    /* INHERITED: Predictions Frame. 
    public FrameV3 predictions = null;
     */

    /* INHERITED: The Mean Squared Error of the prediction for this scoring run. 
    public double MSE = 0.0;
     */

    public ModelMetricsGLRMV99() {
        numerr = 0.0;
        caterr = 0.0;
        numcnt = 0L;
        catcnt = 0L;
        model = null;
        model_checksum = 0L;
        frame = null;
        frame_checksum = 0L;
        description = "";
        model_category = null;
        scoring_time = 0L;
        predictions = null;
        MSE = 0.0;
    }

    /** Return the contents of this object as a JSON String. */
    @Override
    public String toString() {
        return new Gson().toJson(this);
    }
}
